Winx - High Performance MCP Server
A high-performance Rust implementation of the Model Context Protocol (MCP). It provides core tools for shell execution and file management with extreme efficiency.
Re-exports
pub use errors::Result;pub use errors::WinxError;pub use server::start_winx_server;pub use server::WinxService;pub use tools::WinxService as WinxToolsService;