Module read_files

Module read_files 

Implementation of the ReadFiles tool.

This module provides the implementation for the ReadFiles tool, which is used to read and display the contents of files, optionally with line numbers and line range filtering.

Functions

handle_tool_call