Module types

Module types 

Structs

BashCommand
Parameters for the BashCommand tool
BashCommandMode
CodeWriterConfig
ContextSave
Parameters for the ContextSave tool
FileEditMode
FileWriteOrEdit
Parameters for the FileWriteOrEdit tool
Initialize
Parameters for initializing the shell environment
ReadFiles
Parameters for the ReadFiles tool
ReadImage
Parameters for the ReadImage tool
WriteIfEmptyMode

Enums

AllowedCommands
AllowedGlobs
BashCommandAction
Types of actions that can be performed with the BashCommand tool
BashMode
InitializeType
Type of shell environment initialization
ModeName
Modes
SpecialKey
Special key types for shell interaction Matches wcgw Python’s Specials enum exactly

Functions

normalize_thread_id