InitializeType

Enum InitializeType 

pub enum InitializeType {
    FirstCall,
    UserAskedModeChange,
    ResetShell,
    UserAskedChangeWorkspace,
}
Type of shell environment initialization

This enum represents the different ways the Initialize tool can be called, depending on the current state of the conversation and what the user is requesting.

Variants



FirstCall

Initial call at the start of a conversation

This should be used for the first Initialize call in a conversation. It sets up a new shell environment with the specified parameters.



UserAskedModeChange

User requested to change the mode

This should be used when the user asks to switch between modes (e.g., from “wcgw” to “architect” or “code_writer”).



ResetShell

Reset the shell environment due to issues

This should be used when the shell environment appears to be in a bad state and needs to be reset to continue properly.



UserAskedChangeWorkspace

User requested to change the workspace

This should be used when the user asks to switch to a different workspace or project directory during the conversation.