pub struct FileEditMode {
pub allowed_globs: AllowedGlobs,
}Fields
allowed_globs: AllowedGlobsTrait Implementations
Sourceimpl Clone for FileEditMode
impl Clone for FileEditMode
Sourcefn clone(&self) -> FileEditMode
fn clone(&self) -> FileEditMode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileEditMode
impl Debug for FileEditMode
Sourceimpl From<&FileEditMode> for FileEditModeSnapshot
impl From<&FileEditMode> for FileEditModeSnapshot
Sourcefn from(mode: &FileEditMode) -> Self
fn from(mode: &FileEditMode) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for FileEditMode
impl JsonSchema for FileEditMode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FileEditMode
impl PartialEq for FileEditMode
Sourcefn eq(&self, other: &FileEditMode) -> bool
fn eq(&self, other: &FileEditMode) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FileEditMode