pub struct FileWriteOrEdit {
pub file_path: String,
pub percentage_to_change: u32,
pub text_or_search_replace_blocks: String,
pub thread_id: String,
}Expand description
Parameters for the FileWriteOrEdit tool
This struct represents the parameters needed to write or edit a file with optional search/replace blocks for partial edits.
Fields
file_path: StringPath to the file to write or edit
This must be an absolute path (~ allowed).
percentage_to_change: u32Percentage of the file that will be changed
If > 50%, the content is treated as the entire file content. If <= 50%, the content is treated as search/replace blocks.
text_or_search_replace_blocks: StringContent for the file or search/replace blocks
If percentage_to_change > 50%, this is the entire file content.
If percentage_to_change <= 50%, this contains search/replace blocks
in the format:
<<<<<<< SEARCH
old content to find
=======
new content to replace with
>>>>>>> REPLACEthread_id: StringThe thread ID for this session