Module utils

Module utils 

Utility modules for the Winx application.

This module contains various utility functions and types used throughout the application, such as file and path handling, repository analysis, etc.

Modules

bash_parser
command_safety
Command safety and validation module
file_cache
mmap
path
repo
syntax
workspace_stats

Functions

test_json_parsing
Debug helper to test JSON parsing of an Initialize request