Enums
- Path
Security Error - Security error for path validation
Functions
- ensure_
directory_ exists - Ensures a directory exists, creating it if necessary
- expand_
user - Expands a path that starts with ~ to the user’s home directory
- is_
symlink - Check if a path is a symlink without following it
- validate_
path_ in_ workspace - Validates that a path is within the workspace root. Returns the canonicalized path if valid.