Crate winx_code_agent

Crate winx_code_agent 

Winx - High Performance MCP Server

A high-performance Rust implementation of the Model Context Protocol (MCP). It provides core tools for shell execution and file management with extreme efficiency.

Re-exports

pub use errors::Result;
pub use errors::WinxError;
pub use server::start_winx_server;
pub use server::SharedBashState;
pub use server::WinxService;
pub use tools::WinxService as WinxToolsService;

Modules

errors
server
Winx MCP Server implementation using rmcp 0.12.0 Core MCP tools only - High performance shell and file management
state
tools
Tools module for the Winx application.
types
utils
Utility modules for the Winx application.