pub struct PtyShell {
pub last_command: String,
pub output_buffer: String,
pub command_running: bool,
pub output_truncated: bool,
/* private fields */
}Expand description
Real PTY-based interactive shell
Uses portable-pty for true pseudo-terminal functionality, enabling proper handling of interactive programs like sudo, vim, etc.
Fields
last_command: StringLast command executed
output_buffer: StringAccumulated output buffer
command_running: boolWhether a command is currently running
output_truncated: boolFlag for output truncation
Implementations
Sourceimpl PtyShell
impl PtyShell
Sourcepub fn send_command(&mut self, command: &str) -> Result<()>
pub fn send_command(&mut self, command: &str) -> Result<()>
Send a command to the shell and start reading output
Sourcepub fn read_output(&mut self, timeout_secs: f32) -> Result<(String, bool)>
pub fn read_output(&mut self, timeout_secs: f32) -> Result<(String, bool)>
Read output from the PTY with timeout
Returns (output, is_complete) tuple where is_complete indicates
whether the command has finished (prompt detected)
Sourcepub fn send_interrupt(&mut self) -> Result<()>
pub fn send_interrupt(&mut self) -> Result<()>
Send Ctrl+C (interrupt) to the PTY
Sourcepub fn send_suspend(&mut self) -> Result<()>
pub fn send_suspend(&mut self) -> Result<()>
Send Ctrl+Z (suspend) to the PTY
Sourcepub fn send_text(&mut self, text: &str) -> Result<()>
pub fn send_text(&mut self, text: &str) -> Result<()>
Send text directly to the PTY (for interactive input)
Sourcepub fn send_bytes(&mut self, bytes: &[u8]) -> Result<()>
pub fn send_bytes(&mut self, bytes: &[u8]) -> Result<()>
Send raw bytes directly to the PTY.
Sourcepub fn send_special_key(&mut self, key: &str) -> Result<()>
pub fn send_special_key(&mut self, key: &str) -> Result<()>
Send a special key sequence