Structs
- Cell
Style - Compact bitset for terminal text styles.
- Screen
- Represents the current state of a terminal screen
- Screen
Cell - Represents a character with attributes in the terminal
- Screen
Cell Attributes - Container for all possible character attributes
- Terminal
Emulator - Terminal emulator that processes input and maintains screen state
- Terminal
Output Diff - Terminal output difference detector
- Terminal
Performer - Terminal state performer that handles VTE events
Enums
- Terminal
Color - Represents a terminal color
Constants
- DEFAULT_
MAX_ SCREEN_ LINES - Default maximum number of lines to keep in the screen buffer
- MAX_
OUTPUT_ SIZE - Maximum output size in bytes to prevent excessive memory usage
- MAX_
SCREEN_ LINES - Maximum number of lines to keep in the screen buffer
Functions
- incremental_
text - Get incremental text output by comparing old and new terminal states
- render_
terminal_ output - Render terminal output with line wrapping
- strip_
ansi_ codes - Strip ANSI escape codes from a string using a robust regex