Module utils

Module utils 

Utility modules for the Winx application.

This module contains various utility functions and types used throughout the application, such as file and path handling, repository analysis, etc.

Modules

bash_parser
command_safety
Command safety and validation module
display_tree
Directory-tree renderer, ported from wcgw’s display_tree.DirectoryTree.
encoder
Claude-compatible token counting.
file_cache
mmap
output_compress
Conscious compression of noisy shell output.
path
path_prob
File-path relevance ranking, ported from wcgw’s FastPathAnalyzer.
repo
Repository context, ported for parity with wcgw’s repo_context.py.
syntax
workspace_stats

Functions

test_json_parsing
Debug helper to test JSON parsing of an Initialize request