Utility modules for the Winx application.
This module contains various utility functions and types used throughout the application, such as file and path handling, repository analysis, etc.
Modules
- bash_
parser - command_
safety - Command safety and validation module
- display_
tree - Directory-tree renderer, ported from wcgw’s
display_tree.DirectoryTree. - encoder
- Claude-compatible token counting.
- file_
cache - mmap
- path
- path_
prob - File-path relevance ranking, ported from wcgw’s
FastPathAnalyzer. - repo
- Repository context, ported for parity with wcgw’s
repo_context.py. - syntax
- workspace_
stats
Functions
- test_
json_ parsing - Debug helper to test JSON parsing of an Initialize request