Utility modules for the Winx application.
This module contains various utility functions and types used throughout the application, such as file and path handling, repository analysis, etc.
Modules
- bash_
parser - command_
safety - Command safety and validation module
- file_
cache - mmap
- path
- repo
- syntax
Functions
- test_
json_ parsing - Debug helper to test JSON parsing of an Initialize request