Module path

Module path 

Enums

PathSecurityError
Security error for path validation

Functions

ensure_directory_exists
Ensures a directory exists, creating it if necessary
expand_user
Expands a path that starts with ~ to the user’s home directory
is_symlink
Check if a path is a symlink without following it
validate_path_in_workspace
Validates that a path is within the workspace root. Returns the canonicalized path if valid.